@@ -550,6 +550,10 @@ else:
         '/dev/ttyUSB1',
         '/dev/ttyUSB2',
         '/dev/ttyUSB3',
+        '/dev/ttyHS0',
+        '/dev/ttyHS1',
+        '/dev/ttyHS2',
+        '/dev/ttyHS3',
         '/dev/ttyACM0',
         '/dev/ttyACM1',
         '/dev/ttyACM2',
@@ -566,6 +570,7 @@ else:
         (Conn_Cable, '/dev/ttyS%d', (0, 20), ['serial']),
         (Conn_Cable, '/dev/ttyUSB%d', (0, 20), ['serial', 'usb']),
         (Conn_Cable, '/dev/ttyACM%d', (0, 20), ['serial', 'usb']),
+        (Conn_Cable, '/dev/ttyHS%d', (0, 20), ['serial', 'usb']),
         (Conn_Cable, '/dev/cuaU%d', (0, 20), ['serial', 'usb']),
         (Conn_Cable, '/dev/cua%d', (0, 20), ['serial', 'usb']),
         (Conn_BlueRF, '/dev/rfrcomm%d', (0, 20), ['bluetooth']),
